@@ -12,7 +12,7 @@ from django import http, forms
 from django.contrib import messages
 from django.urls import reverse, reverse_lazy
 from django.utils import html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.shortcuts import redirect, render
 from django.views.generic import View, TemplateView
 from django.views.generic.edit import FormView
@@ -712,8 +712,7 @@ class UserCreate(NetpermsMixin, UserFormMixin, OctonetMixin, FormView):
             # Set password
             # refs #12214 #352
             if password:
-                if ((gidNumber and gid and gid.startswith("docent")) or
-                        user_data.get('force_password_change')):
+                if gidNumber and gid and gid.startswith("docent"):
                     self.root_tree.lset(["users", "users", name, "password"], {'password': password, 'shadowLastChange': 0})
                 else:
                     self.root_tree.lset(["users", "users", name, "password"], password)
